@@ -1,12 +1,12 @@
 from .logger import logger, debug, info, error, exception, level
-from .net import (
-    request,
-    get_ip_adr,
-)
+from .net import request, get_ip_adr
 from .shell import shell, bash, pipe
 from .ssh import SSH, ParamSSH
-from .config import get_app_config
+from .dico import Dico
+from .config import Config, get_app_config
 from .tracer import Tracer, trace, set_tracer
 from .fuzzy import fuzzy_select
-from .dico import Dico
 from .func import singleton
+from .rex import Rex, Patterns, Parser
+from .utils import Flags, sorted_dict
+from .files import find, grep
