@@ -1,10 +1,10 @@
-from re import compile as rec
 from functools import partial
+from re import compile as rec
 
 
 # remove ansi codes
 rm_ansi_codes = partial(rec(
-    r'\x1B\[([0-9]{1,3}(;[0-9]{1,2})?)?[mGK](\x0F)?'
+    r'\x1B\[([0-9]{1,3}(;[0-9]{1,2})?)?[mGKJH](\x0F)?'
 ).sub, '')
 
 
