@@ -4,26 +4,32 @@ import nicely
 
 
 class Dico(dict):
+    def _cast(self, value):
+        if isinstance(value, dict) and not isinstance(value, Dico):
+            value = Dico(value)
+        return value
+
     def __getitem__(self, item):
         try:
-            return super().__getitem__(item)
+            value = super().__getitem__(item)
+            return self._cast(value)
         except KeyError:
             value = self[item] = Dico()
             return value
 
     def __getattr__(self, attr):
         if attr.startswith('_'):
-            return super().__getattr__(attr)
+            value = super().__getattr__(attr)
+            return value
         else:
-            return self[attr]
+            value = self[attr]
+            return self._cast(value)
 
     def __setattr__(self, attr, val):
         if attr.startswith('_'):
             super().__setattr__(attr, val)
         else:
-            if isinstance(val, dict) and not isinstance(val, Dico):
-                val = Dico(val)
-            self[attr] = val
+            self[attr] = self._cast(val)
 
     def __getstate__(self):
         return dict(self.items())
