@@ -2,33 +2,41 @@ from functools import partial
 from datetime import datetime
 from io import SEEK_END
 from operator import attrgetter
-from os import scandir
-import os, stat
+import os, os.path, stat
+from os import scandir, getcwd
+from os.path import splitext, splitdrive, isfile, abspath
 from pathlib import Path
 from re import compile, match
 
 
-def files(path):
-    with scandir(path) as ls:
+def walk(path=None, recur=99):
+    path = Path(path).expanduser()
+    with scandir(path or getcwd()) as ls:
         for entry in sorted(ls, key=attrgetter('path')):
             if entry.is_dir(follow_symlinks=False):
-                yield from files(entry.path)
+                if recur:
+                    yield from walk(entry.path, recur-1)
             elif entry.is_file():
                 yield Path(entry)
 
 
 def find(path, name):
-    match = compile(name).search
-    for path in files(path):
-        if match(str(path)):
+    search = compile(name).search
+    for path in walk(path):
+        if search(str(path)):
             yield path
 
 
 def grep(path, rex):
-    rmatch = partial(match, compile(rex))
-    with open(path) as inp:
-        for found in filter(None, map(rmatch, inp)):
-            yield found.groups()
+    search = compile(rex).search
+    for line in open(path):
+        if found := search(line):
+            if groups := found.groupdict():
+                yield groups
+            elif groups := found.groups():
+                yield groups
+            else:
+                yield line.rstrip()
 
 
 class FileStat:
@@ -59,3 +67,10 @@ def last_lines(path, nb_lines, max_line_len=99):
     last = lines[-nb_lines:]
     return last
 
+
+def split(full):
+    path, name = os.path.split(full)
+    drive, path = splitdrive(path)
+    name, ext = splitext(name)
+    ext = ext[1:]
+    return path, name, ext
