@@ -1,7 +1,20 @@
 from collections import defaultdict
+from pathlib import Path
 
 
-def index(makefile='makefile'):
+def get_makefile():
+    for name in (
+        'Makefile',
+        'makefile',
+    ):
+        makefile = Path(name)
+        if makefile.is_file():
+            return makefile
+    raise RuntimeError(' ! Makefile not found')
+
+
+def index(makefile=None):
+    makefile = makefile or get_makefile()
     targets = dict()
     for n, line in enumerate(open(makefile)):
         first, line = ord(line[0]), line.rstrip()
@@ -16,7 +29,8 @@ def index(makefile='makefile'):
     return targets
 
 
-def parse(makefile='makefile'):
+def parse(makefile=None):
+    makefile = makefile or get_makefile()
     targets = defaultdict(list)
     for line in open(makefile):
         first, line = ord(line[0]), line.rstrip()
@@ -31,9 +45,11 @@ def parse(makefile='makefile'):
     return targets
 
 
-def show(makefile='makefile'):
+def show(makefile=None):
+    makefile = makefile or get_makefile()
     for target, commands in parse(makefile).items():
         print(f'{target}:')
         for cmd in commands:
             print(f'    {cmd}')
         print()
+
