@@ -11,8 +11,7 @@ class Primes:
         while True:
             n+=2
             for i in primes:
-                if n%i==0:
-                    break
+                if n%i==0: break
             else:
                 primes.append(n)
                 return n
@@ -27,10 +26,8 @@ class Primes:
 
     def __iter__(self):
         yield 2
-        for p in self.primes:
-            yield p
-        while True:
-            yield self.next()
+        for p in self.primes: yield p
+        while True: yield self.next()
 
     def __contains__(self, num):
         if num>2:
@@ -48,8 +45,7 @@ class Primes:
         last = int(num**.5)
         for p in self:
             if num==p: return [num]
-            if num % p == 0:
-                return [p] + self.factors(num//p)
+            if num % p == 0: return [p] + self.factors(num//p)
             if p>last: return [num]
 
 
